#!/usr/bin/perl -w
# smartmail.pl
#
# written by Erik Huizing
# Wed Aug  9 14:40:42 MDT 2006
# Copyright (c) 2006 Smart Technologies Inc

use Mail::Sendmail;
use MIME::QuotedPrint;
use MIME::Base64;
use strict;

my ( %mail, $boundary, $message, $to, $from, $subject, $zipfile, $encoded_contents );
$subject = '[no subject]';
$from = 'support@smarttech.com';

###################################################
# parse commandline arguments
# for subject(-s), from(-f), to(-t), and zipfile(-z)
#
my $i;
for( $i=0; $i<@ARGV; $i++ )
{
	$_ = $ARGV[$i];
	if ( /-s/ && $i < @ARGV ) { $subject = $ARGV[$i+1]; }
	if ( /-f/ && $i < @ARGV ) { $from = $ARGV[$i+1]; }
	if ( /-t/ && $i < @ARGV ) {
		if( defined( $to ) )
		{
			$to .= ",";
		}
		$to .= $ARGV[$i+1];
	}
	if ( /-z/ && $i < @ARGV ) { $zipfile = $ARGV[$i+1]; }
}

if( ! defined( $to ) )
{
	print "recipient(s) not specified\n";
	exit 1;
}

###################################################
# read the message text from
# standard input
#
while( <STDIN> ) { $message .= $_; }

###################################################
# set up the mail envelope
#
%mail = (
	to => $to,
	from => $from,
	subject => $subject,
	message => $message
);

###################################################
# if a zipfile was specifed and exists, 
# base64-encode its contents 
#
if ( defined($zipfile) )
{
	if ( ! -f $zipfile )
	{
		print "$zipfile not found\n";
		exit 1;
	}
	open( ZIPFILE, $zipfile );
	binmode ZIPFILE; undef $/;
	$encoded_contents = encode_base64(<ZIPFILE>);
	close ZIPFILE;
	my @zippath = split( "/", $zipfile );
	my $zipfilename = $zippath[-1];

	$boundary = "----_=_NextPart001_" . time();

###################################################
# append the encoded zipfile to the message body
#
$mail{message} .= <<EOF;

This is a multi-part message in MIME format.

--$boundary
Content-Type: text/plain;
    charset="us-ascii"
    Content-Transfer-Encoding: quoted-printable

$message

--$boundary
Content-Type: application/x-zip-compressed;
    name="$zipfilename"
Content-Transfer-Encoding: base64
Content-Description: "$zipfilename"
Content-Disposition: attachment;
    filename="$zipfilename"

$encoded_contents

--$boundary--

EOF

	$mail{'content-type'} = "multipart/mixed; boundary=\"$boundary\""
}

###################################################
# use sendmail to send the message
#
if( sendmail %mail )
{
    if( $Mail::Sendmail::error )
    {
        print ("Contents of error:\n$Mail::Sendmail::error\n");
    }
}
else
{
    print ("error sending mail:\n$Mail::Sendmail::error\n");
}

